@@ -1,10 +1,10 @@
 context("test-compare_solutions.R")
 
-x <- estimate_profiles(iris[, 1:4], n_profiles = 1:3)
+x <- estimate_profiles(iris[, 1:4], n_profiles = 2:4)
 
 test_that("compare_solutions works with iris data when we use compare_solutions()
           outside of a pipe", {
-    expect_s3_class(compare_solutions(x), "bestLPA")
+    expect_s3_class(suppressWarnings(compare_solutions(x)), "bestLPA")
 })
 
 # pisaUSA_compare <- pisaUSA15[1:100, ] %>%
